@@ -15,6 +15,22 @@ from fontaine.cmap import library
 from fontaine.const import *
 
 
+def lookup_languages(unichar):
+    try:
+        assert len(unichar) == 1
+    except AssertionError:
+        return []
+
+    charmaps = []
+    for charmap in library.charmaps:
+        glyphs = getattr(charmap, 'glyphs', [])
+        if callable(glyphs):
+            glyphs = glyphs()
+        if ord(unicode(unichar)) in glyphs:
+            charmaps.append(charmap)
+    return charmaps
+
+
 class Font:
 
     def __init__(self, fontfile, charmaps=[]):
